@@ -20,7 +20,7 @@ class PlainTextEditArgs(CommonParameterWidgetArgs):
 
 
 class PlainTextEdit(CommonParameterWidget):
-    HIDE_DEFAULT_WIDGET = True
+    HIDE_DEFAULT_VALUE_WIDGET = True
     SET_DEFAULT_ON_INIT = True
 
     _WidgetArgsClass = PlainTextEditArgs
